@@ -1,14 +1,14 @@
 """
-=================
-PingdomLib v1.2
-=================
+===============
+PingdomLib v1.4
+===============
 Written by: Kenneth Wilke <kenneth.wilke@gmail.com>
 
 This is a python library to provide full access to the pingdom API, along with
 a few additional features to make using the API easier and pythonic.
 
 Usage examples
-=================
+==============
 
 Connecting to pingdom
 ---------------------
@@ -62,6 +62,14 @@ for outage in check.outages():
                                           (outage['timeto'] -
                                           outage['timefrom']) / 60)
 
+Contributors
+============
+* Wil Clouser
+* Ash Berlin
+* Wu Jiang
+* Gertjan Oude Lohuis
+* Benjamin Boudreau
+
 Special thanks
 ==============
 Anders Ekman, Pingdom, for offering warm and helpful support with the API
